==> gvfs-0.0.2.tar.bz2: gvfs-0.0.2/client/gdaemonfilemonitor.h <==
/* GIO - GLib Input, Output and Streaming Library
 * 
 * Copyright (C) 2006-2007 Red Hat, Inc.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General
 * Public License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * Author: Alexander Larsson <alexl@redhat.com>
 */

#ifndef __G_DAEMON_FILE_MONITOR_H__
#define __G_DAEMON_FILE_MONITOR_H__

#include <glib-object.h>
#include <gio/gfilemonitor.h>

G_BEGIN_DECLS

#define G_TYPE_DAEMON_FILE_MONITOR		(g_daemon_file_monitor_get_type ())
#define G_DAEMON_FILE_MONITOR(o)		(G_TYPE_CHECK_INSTANCE_CAST ((o), G_TYPE_DAEMON_FILE_MONITOR, GDaemonFileMonitor))
#define G_DAEMON_FILE_MONITOR_CLASS(k)	(G_TYPE_CHECK_CLASS_CAST ((k), G_TYPE_DAEMON_FILE_MONITOR, GDaemonFileMonitorClass))
#define G_IS_DAEMON_FILE_MONITOR(o)		(G_TYPE_CHECK_INSTANCE_TYPE ((o), G_TYPE_DAEMON_FILE_MONITOR))
#define G_IS_DAEMON_FILE_MONITOR_CLASS(k)	(G_TYPE_CHECK_CLASS_TYPE ((k), G_TYPE_DAEMON_FILE_MONITOR))

typedef struct _GDaemonFileMonitor      GDaemonFileMonitor;
typedef struct _GDaemonFileMonitorClass GDaemonFileMonitorClass;

struct _GDaemonFileMonitorClass {
  GFileMonitorClass parent_class;
};

GType g_daemon_file_monitor_get_type (void) G_GNUC_CONST;

GFileMonitor* g_daemon_file_monitor_new (const char *remote_id,
						   const char *remote_obj_path);


G_END_DECLS

#endif /* __G_DAEMON_FILE_MONITOR_H__ */

==> gvfs-1.6.7.tar.bz2: gvfs-1.6.7/client/gdaemonfilemonitor.h <==
/* GIO - GLib Input, Output and Streaming Library
 * 
 * Copyright (C) 2006-2007 Red Hat, Inc.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General
 * Public License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * Author: Alexander Larsson <alexl@redhat.com>
 */

#ifndef __G_DAEMON_FILE_MONITOR_H__
#define __G_DAEMON_FILE_MONITOR_H__

#include <glib-object.h>
#include <gio/gio.h>

G_BEGIN_DECLS

#define G_TYPE_DAEMON_FILE_MONITOR		(g_daemon_file_monitor_get_type ())
#define G_DAEMON_FILE_MONITOR(o)		(G_TYPE_CHECK_INSTANCE_CAST ((o), G_TYPE_DAEMON_FILE_MONITOR, GDaemonFileMonitor))
#define G_DAEMON_FILE_MONITOR_CLASS(k)	(G_TYPE_CHECK_CLASS_CAST ((k), G_TYPE_DAEMON_FILE_MONITOR, GDaemonFileMonitorClass))
#define G_IS_DAEMON_FILE_MONITOR(o)		(G_TYPE_CHECK_INSTANCE_TYPE ((o), G_TYPE_DAEMON_FILE_MONITOR))
#define G_IS_DAEMON_FILE_MONITOR_CLASS(k)	(G_TYPE_CHECK_CLASS_TYPE ((k), G_TYPE_DAEMON_FILE_MONITOR))

typedef struct _GDaemonFileMonitor      GDaemonFileMonitor;
typedef struct _GDaemonFileMonitorClass GDaemonFileMonitorClass;

struct _GDaemonFileMonitorClass {
  GFileMonitorClass parent_class;
};

GType g_daemon_file_monitor_get_type (void) G_GNUC_CONST;

GFileMonitor* g_daemon_file_monitor_new (const char *remote_id,
						   const char *remote_obj_path);


G_END_DECLS

#endif /* __G_DAEMON_FILE_MONITOR_H__ */
